package models

import (
	"github.com/charmbracelet/log"
	"github.com/gorilla/websocket"
	"sync"
)

// Represents a command from the client (start/stop)
type ClientCommand struct {
	Command  string         `json:"command"`  // Command send to the server
	Password string         `json:"password"` // Pomodoro control password
	Settings PomodoroConfig `json:"settings"` // Pomodoro config
}

// Represents a single client
type Client struct {
	Conn  *websocket.Conn // Websocket connection of the client
	Mutex sync.Mutex      // Mutex used to lock
}

// Sends a message to the websocket.
// Automatically locks and unlocks the client mutex, to ensure that only one goroutine can write at a time.
func (c *Client) SendMessage(messageType int, data []byte) error {
	c.Mutex.Lock()
	defer c.Mutex.Unlock()

	err := c.Conn.WriteMessage(messageType, data)
	if err != nil {
		log.Error("Error writing to WebSocket:", "msg", err)
		c.Conn.Close() // Close the connection on error
	}
	return err
}
